==> qgis_3.0.0.orig.tar.xz: qgis-3.0.0/python/plugins/processing/algs/grass7/ext/v_net_bridge.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    v_net_bridge.py
    ---------------------
    Date                 : December 2015
    Copyright            : (C) 2015 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'December 2015'
__copyright__ = '(C) 2015, Médéric Ribreux'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = '$Format:%H$'

from .v_net import incorporatePoints, variableOutput


def processCommand(alg, parameters, context):
    incorporatePoints(alg, parameters, context)


def processOutputs(alg, parameters, context):
    idx = alg.parameterAsInt(parameters, 'method', context)
    operations = alg.parameterDefinition('method').options()
    operation = operations[idx]

    if operation == 'articulation':
        outputParameter = {'output': ['output', 'point', 2, True]}
    elif operation == 'bridge':
        outputParameter = {'output': ['output', 'line', 1, False]}
    variableOutput(alg, outputParameter, parameters, context)

==> qgis_3.4.10+dfsg.orig.tar.xz: qgis-3.4.10/python/plugins/processing/algs/grass7/ext/v_net_bridge.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    v_net_bridge.py
    ---------------------
    Date                 : December 2015
    Copyright            : (C) 2015 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'December 2015'
__copyright__ = '(C) 2015, Médéric Ribreux'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = '3d97aaae88d41dd5d7809c7fdeb2db74f29a6053'

from .v_net import incorporatePoints, variableOutput


def processCommand(alg, parameters, context, feedback):
    incorporatePoints(alg, parameters, context, feedback)


def processOutputs(alg, parameters, context, feedback):
    idx = alg.parameterAsInt(parameters, 'method', context)
    operations = alg.parameterDefinition('method').options()
    operation = operations[idx]

    if operation == 'articulation':
        outputParameter = {'output': ['output', 'point', 2, True]}
    elif operation == 'bridge':
        outputParameter = {'output': ['output', 'line', 1, False]}
    variableOutput(alg, outputParameter, parameters, context)
